Trait ux::native::PagerExt [−][src]
pub trait PagerExt: 'static {
Show methods
pub fn get_actor_for_page(&self, page: u32) -> Option<Actor>;
pub fn get_current_page(&self) -> u32;
pub fn get_current_page_actor(&self) -> Option<Actor>;
pub fn get_edge_previews(&self) -> bool;
pub fn get_n_pages(&self) -> usize;
pub fn insert_page<P>(&self, child: &P, position: i32)
where
P: Is<Actor>;
pub fn next(&self);
pub fn previous(&self);
pub fn set_current_page(&self, page: u32, animate: bool);
pub fn set_current_page_by_actor<P>(&self, actor: &P, animate: bool)
where
P: Is<Actor>;
pub fn set_edge_previews(&self, edge_previews: bool);
pub fn get_property_page_actor(&self) -> Option<Actor>;
pub fn get_property_page_num(&self) -> u32;
pub fn set_property_page_num(&self, page_num: u32);
pub fn connect_property_edge_previews_notify<F>(
&self,
f: F
) -> SignalHandlerId
where
F: 'static + Fn(&Self);
pub fn connect_property_page_actor_notify<F>(&self, f: F) -> SignalHandlerId
where
F: 'static + Fn(&Self);
pub fn connect_property_page_num_notify<F>(&self, f: F) -> SignalHandlerId
where
F: 'static + Fn(&Self);
}Required methods
pub fn get_actor_for_page(&self, page: u32) -> Option<Actor>[src]
pager_get_actor_for_page: @self: a #Pager @page: a page number
Returns: (transfer none): the #Actor for @page
pub fn get_current_page(&self) -> u32[src]
pager_get_current_page: @self: a #Pager
Returns: the current page number
pub fn get_current_page_actor(&self) -> Option<Actor>[src]
pager_get_current_page_actor: @self: a #Pager
Returns: (transfer none): the #Actor on the current page
pub fn get_edge_previews(&self) -> bool[src]
pager_get_edge_previews: @self: a #Pager
Returns: the value of the #Pager:edge-previews property
pub fn get_n_pages(&self) -> usize[src]
pager_get_n_pages: @self: a #Pager
Returns: the number of pages in this pager
pub fn insert_page<P>(&self, child: &P, position: i32) where
P: Is<Actor>, [src]
P: Is<Actor>,
pager_insert_page: @self: a #Pager @child: the page to insert @position: the position to insert the page. If this is negative, or is larger than the number of pages, it will the last page
Inserts a page into the #Pager at the position specified by @position.
pub fn next(&self)[src]
pager_next: @self: a #Pager
Move to the next page.
pub fn previous(&self)[src]
pager_previous: @self: a #Pager
Move to the previous page.
pub fn set_current_page(&self, page: u32, animate: bool)[src]
pager_set_current_page: @self: a #Pager @page: the page to move to @animate: whether to animate the move between pages
Move to @page.
pub fn set_current_page_by_actor<P>(&self, actor: &P, animate: bool) where
P: Is<Actor>, [src]
P: Is<Actor>,
pager_set_current_page_by_actor: @self: a #Pager @actor: the actor of the page to move to @animate: whether to animate the move between pages
Move to the page containing @actor.
pub fn set_edge_previews(&self, edge_previews: bool)[src]
pager_set_edge_previews: @self: a #Pager @edge_previews: %true to enable edge previews
Sets the #Pager:edge-previews property.
pub fn get_property_page_actor(&self) -> Option<Actor>[src]
pub fn get_property_page_num(&self) -> u32[src]
pub fn set_property_page_num(&self, page_num: u32)[src]
pub fn connect_property_edge_previews_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&Self), [src]
F: 'static + Fn(&Self),
pub fn connect_property_page_actor_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&Self), [src]
F: 'static + Fn(&Self),
pub fn connect_property_page_num_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&Self), [src]
F: 'static + Fn(&Self),
Implementors
impl<O> PagerExt for O where
O: Is<Pager>, [src]
O: Is<Pager>,
pub fn get_actor_for_page(&self, page: u32) -> Option<Actor>[src]
pager_get_actor_for_page: @self: a #Pager @page: a page number
Returns: (transfer none): the #Actor for @page
pub fn get_current_page(&self) -> u32[src]
pager_get_current_page: @self: a #Pager
Returns: the current page number
pub fn get_current_page_actor(&self) -> Option<Actor>[src]
pager_get_current_page_actor: @self: a #Pager
Returns: (transfer none): the #Actor on the current page
pub fn get_edge_previews(&self) -> bool[src]
pager_get_edge_previews: @self: a #Pager
Returns: the value of the #Pager:edge-previews property
pub fn get_n_pages(&self) -> usize[src]
pager_get_n_pages: @self: a #Pager
Returns: the number of pages in this pager
pub fn insert_page<P>(&self, child: &P, position: i32) where
P: Is<Actor>, [src]
P: Is<Actor>,
pager_insert_page: @self: a #Pager @child: the page to insert @position: the position to insert the page. If this is negative, or is larger than the number of pages, it will the last page
Inserts a page into the #Pager at the position specified by @position.
pub fn next(&self)[src]
pager_next: @self: a #Pager
Move to the next page.
pub fn previous(&self)[src]
pager_previous: @self: a #Pager
Move to the previous page.
pub fn set_current_page(&self, page: u32, animate: bool)[src]
pager_set_current_page: @self: a #Pager @page: the page to move to @animate: whether to animate the move between pages
Move to @page.
pub fn set_current_page_by_actor<P>(&self, actor: &P, animate: bool) where
P: Is<Actor>, [src]
P: Is<Actor>,
pager_set_current_page_by_actor: @self: a #Pager @actor: the actor of the page to move to @animate: whether to animate the move between pages
Move to the page containing @actor.
pub fn set_edge_previews(&self, edge_previews: bool)[src]
pager_set_edge_previews: @self: a #Pager @edge_previews: %true to enable edge previews
Sets the #Pager:edge-previews property.
pub fn get_property_page_actor(&self) -> Option<Actor>[src]
pub fn get_property_page_num(&self) -> u32[src]
pub fn set_property_page_num(&self, page_num: u32)[src]
pub fn connect_property_edge_previews_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&O), [src]
F: 'static + Fn(&O),
pub fn connect_property_page_actor_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&O), [src]
F: 'static + Fn(&O),
pub fn connect_property_page_num_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&O), [src]
F: 'static + Fn(&O),