Enum ux::prelude::dx::FeatureID [−][src]
#[non_exhaustive]
pub enum FeatureID {
Show variants
OglFeatureIdTextureNpotBasic,
OglFeatureIdTextureNpotMipmap,
OglFeatureIdTextureNpotRepeat,
OglFeatureIdTextureNpot,
OglFeatureIdTextureRectangle,
OglFeatureIdTexture3d,
OglFeatureIdGlsl,
OglFeatureIdArbfp,
OglFeatureIdOffscreen,
OglFeatureIdOffscreenMultisample,
OglFeatureIdOnscreenMultiple,
OglFeatureIdUnsignedIntIndices,
OglFeatureIdDepthRange,
OglFeatureIdPointSprite,
OglFeatureIdMapBufferForRead,
OglFeatureIdMapBufferForWrite,
OglFeatureIdMirroredRepeat,
OglFeatureIdSwapBuffersEvent,
OglFeatureIdGles2Context,
OglFeatureIdDepthTexture,
OglFeatureIdPresentationTime,
OglFeatureIdFence,
OglFeatureIdPerVertexPointSize,
OglFeatureIdTextureRg,
OglFeatureIdBufferAge,
// some variants omitted
}All the capabilities that can vary between different GPUs supported
by Cogl. Applications that depend on any of these features should explicitly
check for them using has_feature or has_features.
Variants (Non-exhaustive)
The hardware supports non power
of two textures, but you also need to check the
FeatureID::OglFeatureIdTextureNpotMipmap and FeatureID::OglFeatureIdTextureNpotRepeat
features to know if the hardware supports npot texture mipmaps
or repeat modes other than
PipelineWrapMode::ClampToEdge respectively.
Mipmapping is supported in conjuntion with non power of two textures.
Repeat modes other than
PipelineWrapMode::ClampToEdge are supported by the
hardware.
Non power of two textures are supported
by the hardware. This is a equivalent to the
FeatureID::OglFeatureIdTextureNpotBasic, FeatureID::OglFeatureIdTextureNpotMipmap
and FeatureID::OglFeatureIdTextureNpotRepeat features combined.
Support for rectangular textures with non-normalized texture coordinates.
3D texture support
GLSL support
ARBFP support
Offscreen rendering support
Multisample support for offscreen framebuffers
Multiple onscreen framebuffers supported.
Set if
IndicesType::Int is supported in
Indices::new.
pipeline_set_depth_range support
Whether
Pipeline::set_layer_point_sprite_coords_enabled is supported.
Whether buffer_map is
supported with CoglBufferAccess including read support.
Whether buffer_map is
supported with CoglBufferAccess including write support.
Whether
PipelineWrapMode::MirroredRepeat is supported.
Available if the window system supports reporting an event for swap buffer completions.
Whether creating new GLES2 contexts is suported.
Whether Framebuffer support rendering
the depth buffer to a texture.
Whether frame presentation
time stamps will be recorded in FrameInfo objects.
Whether point_size_in can be used as an attribute to set a per-vertex point size.
Support for
TextureComponents::Rg as the internal components of a
texture.
Available if the age of Onscreen back
buffers are tracked and so Onscreen::get_buffer_age can be
expected to return age values other than 0.