Struct ux::u57
[−]
[src]
pub struct u57(_);
The 57-bit unsigned integer type.
Methods
impl u57[src]
impl u57[src]
pub fn min_value() -> u57[src]
Returns the smallest value that can be represented by this integer type.
pub fn max_value() -> u57[src]
Returns the largest value that can be represented by this integer type.
pub fn new(value: u64) -> u57[src]
Crates a new variable
This function mainly exists as there is currently not a better way to construct these types. May be deprecated or removed if a better way to construct these types becomes available.
Examples
Basic usage:
use ux::*; assert_eq!(u31::new(64), u31::from(64u8));
Panic
This function will panic if value is not representable by this type
pub fn wrapping_sub(self, rhs: Self) -> Self[src]
Wrapping (modular) subtraction. Computes self - other,
wrapping around at the boundary of the type.
Examples
Basic usage:
use ux::*; assert_eq!(i5::MIN.wrapping_sub(i5::new(1)), i5::MAX); assert_eq!(i5::new(-10).wrapping_sub(i5::new(5)), i5::new(-15)); assert_eq!(i5::new(-15).wrapping_sub(i5::new(5)), i5::new(12));
pub fn wrapping_add(self, rhs: Self) -> Self[src]
Wrapping (modular) addition. Computes self + other,
wrapping around at the boundary of the type.
Examples
Basic usage:
use ux::*; assert_eq!(i5::MAX.wrapping_add(i5::new(1)), i5::MIN); assert_eq!(i5::new(10).wrapping_add(i5::new(5)), i5::new(15)); assert_eq!(i5::new(15).wrapping_add(i5::new(5)), i5::new(-12));