Trait ux::ScrollBarExt [−][src]
pub trait ScrollBarExt: 'static {
pub fn get_adjustment(&self) -> Option<Adjustment>;
pub fn get_orientation(&self) -> Orientation;
pub fn set_adjustment<P>(&self, adjustment: &P)
where
P: Is<Adjustment>;
pub fn set_orientation(&self, orientation: Orientation);
pub fn connect_scroll_start<F>(&self, f: F) -> SignalHandlerId
where
F: 'static + Fn(&Self);
pub fn connect_scroll_stop<F>(&self, f: F) -> SignalHandlerId
where
F: 'static + Fn(&Self);
pub fn connect_property_adjustment_notify<F>(&self, f: F) -> SignalHandlerId
where
F: 'static + Fn(&Self);
pub fn connect_property_orientation_notify<F>(
&self,
f: F
) -> SignalHandlerId
where
F: 'static + Fn(&Self);
}Required methods
pub fn get_adjustment(&self) -> Option<Adjustment>[src]
get_adjustment: @bar: a #ScrollBar
Gets the adjustment object that stores the current position of the scrollbar.
pub fn get_orientation(&self) -> Orientation[src]
pub fn set_adjustment<P>(&self, adjustment: &P) where
P: Is<Adjustment>, [src]
P: Is<Adjustment>,
pub fn set_orientation(&self, orientation: Orientation)[src]
pub fn connect_scroll_start<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&Self), [src]
F: 'static + Fn(&Self),
pub fn connect_scroll_stop<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&Self), [src]
F: 'static + Fn(&Self),
pub fn connect_property_adjustment_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&Self), [src]
F: 'static + Fn(&Self),
pub fn connect_property_orientation_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&Self), [src]
F: 'static + Fn(&Self),
Implementors
impl<O> ScrollBarExt for O where
O: Is<ScrollBar>, [src]
O: Is<ScrollBar>,
pub fn get_adjustment(&self) -> Option<Adjustment>[src]
get_adjustment: @bar: a #ScrollBar
Gets the adjustment object that stores the current position of the scrollbar.
pub fn get_orientation(&self) -> Orientation[src]
pub fn set_adjustment<P>(&self, adjustment: &P) where
P: Is<Adjustment>, [src]
P: Is<Adjustment>,
pub fn set_orientation(&self, orientation: Orientation)[src]
pub fn connect_scroll_start<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&O), [src]
F: 'static + Fn(&O),
pub fn connect_scroll_stop<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&O), [src]
F: 'static + Fn(&O),
pub fn connect_property_adjustment_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&O), [src]
F: 'static + Fn(&O),
pub fn connect_property_orientation_notify<F>(&self, f: F) -> SignalHandlerId where
F: 'static + Fn(&O), [src]
F: 'static + Fn(&O),